# Spark App Library

## Usage
To install from pypi:

    pip install spark-app-library

Released versions on package registry:

    https://gitlab.snapp.ir/data-team/data-engineering/apache-spark/spark-app-library/-/packages
